@@ -4,14 +4,87 @@ import (
 	"errors"
 	"testing"
 
-	"github.com/minio/minio-go"
-	"github.com/minio/minio-go/pkg/credentials"
+	"github.com/minio/minio-go/v6"
+	"github.com/minio/minio-go/v6/pkg/credentials"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
 	"gitlab.com/gitlab-org/gitlab-runner/common"
 )
 
+type minioClientInitializationTest struct {
+	errorOnInitialization bool
+	configurationFactory  func() *common.CacheConfig
+
+	expectedToUseIAM bool
+	expectedInsecure bool
+}
+
+func TestMinioClientInitialization(t *testing.T) {
+	tests := map[string]minioClientInitializationTest{
+		"error-on-initialization": {
+			errorOnInitialization: true,
+			configurationFactory:  defaultCacheFactory,
+		},
+		"all-credentials-empty": {
+			configurationFactory: emptyCredentialsCacheFactory,
+			expectedToUseIAM:     true,
+		},
+		"serverAddress-empty": {
+			configurationFactory: emptyServerAddressFactory,
+			expectedToUseIAM:     true,
+		},
+		"accessKey-empty": {
+			configurationFactory: emptyAccessKeyFactory,
+			expectedToUseIAM:     true,
+		},
+		"secretKey-empty": {
+			configurationFactory: emptySecretKeyFactory,
+			expectedToUseIAM:     true,
+		},
+		"only-ServerAddress-defined": {
+			configurationFactory: onlyServerAddressFactory,
+			expectedToUseIAM:     true,
+		},
+		"only-AccessKey-defined": {
+			configurationFactory: onlyAccessKeyFactory,
+			expectedToUseIAM:     true,
+		},
+		"only-SecretKey-defined": {
+			configurationFactory: onlySecretKeyFactory,
+			expectedToUseIAM:     true,
+		},
+		"should-use-explicit-credentials": {
+			configurationFactory: defaultCacheFactory,
+		},
+		"should-use-explicit-credentials-with-insecure": {
+			configurationFactory: insecureCacheFactory,
+			expectedInsecure:     true,
+		},
+	}
+
+	for testName, test := range tests {
+		t.Run(testName, func(t *testing.T) {
+			cleanupMinioMock := runOnFakeMinio(t, test)
+			defer cleanupMinioMock()
+
+			cleanupMinioCredentialsMock := runOnFakeMinioWithCredentials(t, test)
+			defer cleanupMinioCredentialsMock()
+
+			cacheConfig := test.configurationFactory()
+			client, err := newMinioClient(cacheConfig.S3)
+
+			if test.errorOnInitialization {
+				assert.Error(t, err, "test error")
+				return
+			}
+
+			require.NoError(t, err)
+			assert.NotNil(t, client)
+		})
+	}
+}
+
 func insecureCacheFactory() *common.CacheConfig {
 	cacheConfig := defaultCacheFactory()
 	cacheConfig.S3.Insecure = true
@@ -28,12 +101,49 @@ func emptyCredentialsCacheFactory() *common.CacheConfig {
 	return cacheConfig
 }
 
-type minioClientInitializationTest struct {
-	errorOnInitialization bool
-	configurationFactory  func() *common.CacheConfig
+func emptyServerAddressFactory() *common.CacheConfig {
+	cacheConfig := emptyCredentialsCacheFactory()
+	cacheConfig.S3.AccessKey = "TOKEN"
+	cacheConfig.S3.SecretKey = "TOKEN"
 
-	expectedToUseIAM bool
-	expectedInsecure bool
+	return cacheConfig
+}
+
+func emptyAccessKeyFactory() *common.CacheConfig {
+	cacheConfig := emptyCredentialsCacheFactory()
+	cacheConfig.S3.ServerAddress = "s3.amazonaws.com"
+	cacheConfig.S3.SecretKey = "TOKEN"
+
+	return cacheConfig
+}
+
+func emptySecretKeyFactory() *common.CacheConfig {
+	cacheConfig := emptyCredentialsCacheFactory()
+	cacheConfig.S3.ServerAddress = "s3.amazonaws.com"
+	cacheConfig.S3.AccessKey = "TOKEN"
+
+	return cacheConfig
+}
+
+func onlyServerAddressFactory() *common.CacheConfig {
+	cacheConfig := emptyCredentialsCacheFactory()
+	cacheConfig.S3.ServerAddress = "s3.amazonaws.com"
+
+	return cacheConfig
+}
+
+func onlyAccessKeyFactory() *common.CacheConfig {
+	cacheConfig := emptyCredentialsCacheFactory()
+	cacheConfig.S3.AccessKey = "TOKEN"
+
+	return cacheConfig
+}
+
+func onlySecretKeyFactory() *common.CacheConfig {
+	cacheConfig := emptyCredentialsCacheFactory()
+	cacheConfig.S3.SecretKey = "TOKEN"
+
+	return cacheConfig
 }
 
 func runOnFakeMinio(t *testing.T, test minioClientInitializationTest) func() {
@@ -89,44 +199,3 @@ func runOnFakeMinioWithCredentials(t *testing.T, test minioClientInitializationT
 		newMinioWithCredentials = oldNewMinioWithCredentials
 	}
 }
-
-func TestMinioClientInitialization(t *testing.T) {
-	tests := map[string]minioClientInitializationTest{
-		"error-on-initialization": {
-			errorOnInitialization: true,
-			configurationFactory:  defaultCacheFactory,
-		},
-		"should-use-IAM": {
-			configurationFactory: emptyCredentialsCacheFactory,
-			expectedToUseIAM:     true,
-		},
-		"should-use-explicit-credentials": {
-			configurationFactory: defaultCacheFactory,
-		},
-		"should-use-explicit-credentials-with-insecure": {
-			configurationFactory: insecureCacheFactory,
-			expectedInsecure:     true,
-		},
-	}
-
-	for testName, test := range tests {
-		t.Run(testName, func(t *testing.T) {
-			cleanupMinioMock := runOnFakeMinio(t, test)
-			defer cleanupMinioMock()
-
-			cleanupMinioCredentialsMock := runOnFakeMinioWithCredentials(t, test)
-			defer cleanupMinioCredentialsMock()
-
-			cacheConfig := test.configurationFactory()
-			client, err := newMinioClient(cacheConfig.S3)
-
-			if test.errorOnInitialization {
-				assert.Error(t, err, "test error")
-				return
-			}
-
-			require.NoError(t, err)
-			assert.NotNil(t, client)
-		})
-	}
-}
