@@ -72,7 +72,7 @@ func (b *buildsHelper) getRunnerCounter(runner *common.RunnerConfig) *runnerCoun
 		b.counters = make(map[string]*runnerCounter)
 	}
 
-	counter, _ := b.counters[runner.Token]
+	counter := b.counters[runner.Token]
 	if counter == nil {
 		counter = &runnerCounter{}
 		b.counters[runner.Token] = counter
@@ -187,8 +187,6 @@ func (b *buildsHelper) addBuild(build *common.Build) {
 
 	b.builds = append(b.builds, build)
 	b.jobsTotal.WithLabelValues(build.Runner.ShortDescription()).Inc()
-
-	return
 }
 
 func (b *buildsHelper) removeBuild(deleteBuild *common.Build) bool {
@@ -222,11 +220,7 @@ func (b *buildsHelper) statesAndStages() map[statePermutation]int {
 	data := make(map[statePermutation]int)
 	for _, build := range b.builds {
 		state := newStatePermutationFromBuild(build)
-		if _, ok := data[state]; ok {
-			data[state]++
-		} else {
-			data[state] = 1
-		}
+		data[state]++
 	}
 	return data
 }
@@ -290,43 +284,10 @@ func (b *buildsHelper) Collect(ch chan<- prometheus.Metric) {
 }
 
 func (b *buildsHelper) ListJobsHandler(w http.ResponseWriter, r *http.Request) {
-	version := r.URL.Query().Get("v")
-	if version == "" {
-		version = "1"
-	}
-
-	handlers := map[string]http.HandlerFunc{
-		"1": b.listJobsHandlerV1,
-		"2": b.listJobsHandlerV2,
-	}
-
-	handler, ok := handlers[version]
-	if !ok {
-		w.WriteHeader(http.StatusNotFound)
-		fmt.Fprintf(w, "Request version %q not supported", version)
-		return
-	}
-
-	w.Header().Add("X-List-Version", version)
+	w.Header().Add("X-List-Version", "2")
 	w.Header().Add("Content-Type", "text/plain")
 	w.WriteHeader(http.StatusOK)
 
-	handler(w, r)
-}
-
-func (b *buildsHelper) listJobsHandlerV1(w http.ResponseWriter, r *http.Request) {
-	for _, job := range b.builds {
-		fmt.Fprintf(
-			w,
-			"id=%d url=%s state=%s stage=%s executor_stage=%s\n",
-			job.ID, job.RepoCleanURL(),
-			job.CurrentState, job.CurrentStage, job.CurrentExecutorStage(),
-		)
-	}
-
-}
-
-func (b *buildsHelper) listJobsHandlerV2(w http.ResponseWriter, r *http.Request) {
 	for _, job := range b.builds {
 		url := CreateJobURL(job.RepoCleanURL(), job.ID)
 
@@ -339,7 +300,7 @@ func (b *buildsHelper) listJobsHandlerV2(w http.ResponseWriter, r *http.Request)
 }
 
 func CreateJobURL(projectURL string, jobID int) string {
-	r := regexp.MustCompile("(\\.git$)?")
+	r := regexp.MustCompile(`(\.git$)?`)
 	URL := r.ReplaceAllString(projectURL, "")
 
 	return fmt.Sprintf("%s/-/jobs/%d", URL, jobID)
