@@ -5,7 +5,9 @@ import (
 	"io"
 
 	"github.com/sirupsen/logrus"
+
 	"gitlab.com/gitlab-org/gitlab-runner/helpers"
+	"gitlab.com/gitlab-org/gitlab-runner/helpers/process"
 	url_helpers "gitlab.com/gitlab-org/gitlab-runner/helpers/url"
 )
 
@@ -94,3 +96,23 @@ func NewBuildLogger(log JobTrace, entry *logrus.Entry) BuildLogger {
 		entry: entry,
 	}
 }
+
+type ProcessLoggerAdapter struct {
+	buildLogger BuildLogger
+}
+
+func NewProcessLoggerAdapter(buildlogger BuildLogger) *ProcessLoggerAdapter {
+	return &ProcessLoggerAdapter{
+		buildLogger: buildlogger,
+	}
+}
+
+func (l *ProcessLoggerAdapter) WithFields(fields logrus.Fields) process.Logger {
+	l.buildLogger = l.buildLogger.WithFields(fields)
+
+	return l
+}
+
+func (l *ProcessLoggerAdapter) Warn(args ...interface{}) {
+	l.buildLogger.Warningln(args...)
+}
