@@ -221,7 +221,15 @@ func (e *executor) Run(cmd common.ExecutorCommand) error {
 		return err
 	}
 
-	args := append(e.config.RunArgs, scriptFile, string(cmd.Stage))
+	// TODO: Remove this translation in 14.0 - https://gitlab.com/gitlab-org/gitlab-runner/-/issues/26426
+	stage := cmd.Stage
+	if stage == "step_script" {
+		e.BuildLogger.Warningln("Starting with version 14.0 the 'build_script' stage " +
+			"will be replaced with 'step_script': https://gitlab.com/gitlab-org/gitlab-runner/-/issues/26426")
+		stage = "build_script"
+	}
+
+	args := append(e.config.RunArgs, scriptFile, string(stage))
 
 	opts := prepareCommandOpts{
 		executable: e.config.RunExec,
