@@ -466,6 +466,8 @@ func TestExecutor_Run(t *testing.T) {
 			}),
 			assertCommandFactory: func(t *testing.T, tt executorTestCase, ctx context.Context, executable string, args []string, options process.CommandOptions) {
 				assert.Equal(t, tt.config.Custom.RunExec, executable)
+				assert.Len(t, args, 2)
+				assert.Equal(t, "build_script", args[1])
 			},
 		},
 		"Run executes job with error": {
@@ -496,6 +498,7 @@ func TestExecutor_Run(t *testing.T) {
 
 			err = e.Run(common.ExecutorCommand{
 				Context: context.Background(),
+				Stage:   "step_script",
 			})
 
 			assertOutput(t, tt, out)
