@@ -220,7 +220,7 @@ func (s *executor) runWithExecLegacy(cmd common.ExecutorCommand) error {
 			return err
 		}
 
-		err = s.setupBuildPod()
+		err = s.setupBuildPod(nil)
 		if err != nil {
 			return err
 		}
@@ -325,7 +325,7 @@ func (s *executor) ensurePodsConfigured(ctx context.Context) error {
 		return fmt.Errorf("setting up scripts configMap: %w", err)
 	}
 
-	err = s.setupBuildPod()
+	err = s.setupBuildPod([]api.Container{s.buildLogPermissionsInitContainer()})
 	if err != nil {
 		return fmt.Errorf("setting up build pod: %w", err)
 	}
@@ -344,6 +344,21 @@ func (s *executor) ensurePodsConfigured(ctx context.Context) error {
 	return nil
 }
 
+func (s *executor) buildLogPermissionsInitContainer() api.Container {
+	// Since we mount the logs an emptyDir volume, the directory is owned by root.
+	// This makes it impossible for other users to write to the shared log without
+	// explicitly giving them permissions. More info at https://github.com/kubernetes/kubernetes/issues/2630
+	chmod := fmt.Sprintf("touch %s && chmod -R 777 %s", s.logFile(), s.logsDir())
+
+	return api.Container{
+		Name:            "change-logs-permissions",
+		Image:           "busybox",
+		Command:         []string{"sh", "-c", chmod},
+		VolumeMounts:    s.getVolumeMounts(),
+		ImagePullPolicy: api.PullPolicy(s.pullPolicy),
+	}
+}
+
 func (s *executor) buildCommandForStage(stage common.BuildStage) string {
 	return fmt.Sprintf("%s 2>&1 | tee -a %s", s.scriptPath(stage), s.logFile())
 }
@@ -847,7 +862,7 @@ func (s *executor) createHostAlias() (*api.HostAlias, error) {
 	return &servicesHostAlias, nil
 }
 
-func (s *executor) setupBuildPod() error {
+func (s *executor) setupBuildPod(initContainers []api.Container) error {
 	s.Debugln("Setting up build pod")
 
 	podServices := make([]api.Container, len(s.options.Services))
@@ -889,7 +904,7 @@ func (s *executor) setupBuildPod() error {
 		return err
 	}
 
-	podConfig := s.preparePodConfig(labels, annotations, podServices, imagePullSecrets, hostAlias)
+	podConfig := s.preparePodConfig(labels, annotations, podServices, imagePullSecrets, hostAlias, initContainers)
 
 	s.Debugln("Creating build pod")
 	pod, err := s.kubeClient.CoreV1().Pods(s.configurationOverwrites.namespace).Create(&podConfig)
@@ -906,7 +921,13 @@ func (s *executor) setupBuildPod() error {
 	return nil
 }
 
-func (s *executor) preparePodConfig(labels, annotations map[string]string, services []api.Container, imagePullSecrets []api.LocalObjectReference, hostAlias *api.HostAlias) api.Pod {
+func (s *executor) preparePodConfig(
+	labels, annotations map[string]string,
+	services []api.Container,
+	imagePullSecrets []api.LocalObjectReference,
+	hostAlias *api.HostAlias,
+	initContainers []api.Container,
+) api.Pod {
 	buildImage := s.Build.GetAllVariables().ExpandValue(s.options.Image.Name)
 
 	pod := api.Pod{
@@ -922,6 +943,7 @@ func (s *executor) preparePodConfig(labels, annotations map[string]string, servi
 			RestartPolicy:      api.RestartPolicyNever,
 			NodeSelector:       s.Config.Kubernetes.NodeSelector,
 			Tolerations:        s.Config.Kubernetes.GetNodeTolerations(),
+			InitContainers:     initContainers,
 			Containers: append([]api.Container{
 				// TODO use the build and helper template here
 				s.buildContainer(buildContainerName, buildImage, s.options.Image, s.buildRequests, s.buildLimits, s.BuildShell.DockerCommand...),
